from . import (FrequenciesExtras, GenotypeExtras, TranscriptExtras, 
               ConsequenceExtras, GeneExtras)

#GeneExtras, AnnotationExtras
class VariantExtras(FrequenciesExtras, GenotypeExtras, TranscriptExtras, 
ConsequenceExtras, GeneExtras):
    """docstring for VariantExtras"""
    pass
