# -*- coding: utf-8 -*-
from .dotdict import DotDict
from .mixins import PedigreeHumanMixin
from .individual import Individual
from .case import Case
from .transcript import Transcript
from .gene import Gene
from .compound import Compound
from .genotype import Genotype
from .variant import (Variant, Genotype, Gene,
Compound)
