from . import (GeneExtras, FrequenciesExtras, ConsequenceExtras, 
               TranscriptExtras, GenotypeExtras, AnnotationExtras)

class VariantExtras(GeneExtras, FrequenciesExtras, ConsequenceExtras,
                    TranscriptExtras, GenotypeExtras, AnnotationExtras):
    """docstring for VariantExtras"""
    pass
        