.list-group.is-scrollable {
  max-height: 250px;
  overflow-y: auto;
}

button.no-style {
  background: none;
  border: none;
  padding: 0;
}

.overflow-auto {
  overflow: auto;
}

.label {
  display: inline-block;
}
