# -*- coding: utf-8 -*-
"""
test_puzzle
----------------------------------

Tests for `puzzle` module.
"""
import pytest
import puzzle


class TestPuzzle(object):
    @classmethod
    def set_up(self):
        pass

    def test_something(self):
        pass

    @classmethod
    def tear_down(self):
        pass
