{% extends "layouts/base.html" %}

{% block container %}
  <div class="page-header"><h3>{{ resource.name }}</h3></div>
  <p>
    <a href="{{ url_for('public.individual', ind_id=resource.individual.ind_id) }}">
      {{ resource.individual.ind_id }}
    </a>
  </p>

  <div class="row">
    <div class="col-md-12">
      <a href="{{ url_for('public.resource', resource_id=resource.id, raw=True) }}">
        <img class="img-responsive" src="{{ url_for('public.resource', resource_id=resource.id, raw=True) }}">
      </a>
    </div>
  </div>
{% endblock %}
